smalto/lustre/themes

Pre-built inline-styled theme configurations for smalto_lustre.

Auto-generated by tools/theme_converter from the CSS themes in themes/. Do not edit by hand — re-run the converter instead.

Each function returns a Config(msg) with inline-styled <span> elements matching the corresponding CSS theme from the smalto themes collection. Unlike the CSS themes, these configs require no external stylesheet — all styles are applied directly to the elements.

Usage

import smalto
import smalto/languages/python
import smalto/lustre as smalto_lustre
import smalto/lustre/themes

let tokens = smalto.to_tokens("print('hello')", python.grammar())
let elements = smalto_lustre.to_lustre(tokens, themes.dracula())

Available themes (45)

Values

pub fn a11y_dark() -> lustre.Config(msg)

a11y-dark theme for JavaScript, CSS, and HTML Based on the okaidia theme: https://github.com/PrismJS/prism/blob/gh-pages

pub fn atom_dark() -> lustre.Config(msg)

atom-dark theme for prism.js Based on Atom’s atom-dark theme: https://github.com/atom/atom-dark-syntax @author Joe G

pub fn base16_ateliersulphurpool_light() -> lustre.Config(msg)

base16 ateliersulphurpool.light theme

pub fn cb() -> lustre.Config(msg)

cb theme

pub fn coldark_cold() -> lustre.Config(msg)

Coldark Theme for Prism.js Theme variation: Cold Tested with HTML, CSS, JS, JSON, PHP, YAML, Bash script @author Armand

pub fn coldark_dark() -> lustre.Config(msg)

Coldark Theme for Prism.js Theme variation: Dark Tested with HTML, CSS, JS, JSON, PHP, YAML, Bash script @author Armand

pub fn coy() -> lustre.Config(msg)

prism.js Coy theme for JavaScript, CoffeeScript, CSS and HTML Based on https://github.com/tshedor/workshop-wp-theme (Exa

pub fn coy_without_shadows() -> lustre.Config(msg)

Coy without shadows Based on Tim Shedor’s Coy theme for prism.js Author: RunDevelopment

pub fn darcula() -> lustre.Config(msg)

Darcula theme Adapted from a theme based on: IntelliJ Darcula Theme (https://github.com/bulenkov/Darcula) @author Alexan

pub fn dark() -> lustre.Config(msg)

prism.js Dark theme for JavaScript, CSS and HTML Based on the slides of the talk “/Reg(exp){2}lained/” @author Lea Verou

pub fn default() -> lustre.Config(msg)

prism.js default theme for JavaScript, CSS and HTML Based on dabblet (http://dabblet.com) @author Lea Verou

pub fn dracula() -> lustre.Config(msg)

Dracula Theme originally by Zeno Rocha [@zenorocha] https://draculatheme.com/ Ported for PrismJS by Albert Vallverdu [@b

pub fn duotone_dark() -> lustre.Config(msg)

duotone dark theme

pub fn duotone_earth() -> lustre.Config(msg)

duotone earth theme

pub fn duotone_forest() -> lustre.Config(msg)

duotone forest theme

pub fn duotone_light() -> lustre.Config(msg)

duotone light theme

pub fn duotone_sea() -> lustre.Config(msg)

duotone sea theme

pub fn duotone_space() -> lustre.Config(msg)

duotone space theme

pub fn funky() -> lustre.Config(msg)

prism.js Funky theme Based on “Polyfilling the gaps” talk slides http://lea.verou.me/polyfilling-the-gaps/ @author Lea V

pub fn ghcolors() -> lustre.Config(msg)

GHColors theme by Avi Aryan (http://aviaryan.in) Inspired by Github syntax coloring

pub fn gruvbox_dark() -> lustre.Config(msg)

Gruvbox dark theme Adapted from a theme based on: Vim Gruvbox dark Theme (https://github.com/morhetz/gruvbox) @author Az

pub fn gruvbox_light() -> lustre.Config(msg)

Gruvbox light theme Based on Gruvbox: https://github.com/morhetz/gruvbox Adapted from PrismJS gruvbox-dark theme: https:

pub fn holi_theme() -> lustre.Config(msg)

MIT License Copyright (c) 2021 Ayush Saini Holi Theme for prism.js @author Ayush Saini <@AyushCodes on Twitter>

pub fn hopscotch() -> lustre.Config(msg)

hopscotch theme

pub fn laserwave() -> lustre.Config(msg)

laserwave theme

pub fn lucario() -> lustre.Config(msg)

Lucario Theme originally by Raphael Amorim [@raphamorim] https://github.com/raphamorim/lucario Ported for PrismJS by Chr

pub fn material_dark() -> lustre.Config(msg)

material dark theme

pub fn material_light() -> lustre.Config(msg)

material light theme

pub fn material_oceanic() -> lustre.Config(msg)

material oceanic theme

pub fn night_owl() -> lustre.Config(msg)

MIT License Copyright (c) 2018 Sarah Drasner Sarah Drasner’s[@sdras] Night Owl Ported by Sara vieria [@SaraVieira] Added

pub fn nord() -> lustre.Config(msg)

Nord Theme Originally by Arctic Ice Studio https://nordtheme.com Ported for PrismJS by Zane Hitchcoxc (@zwhitchcox) and

pub fn okaidia() -> lustre.Config(msg)

okaidia theme for JavaScript, CSS and HTML Loosely based on Monokai textmate theme by http://www.monokai.nl/ @author oco

pub fn one_dark() -> lustre.Config(msg)

One Dark theme for prism.js Based on Atom’s One Dark theme: https://github.com/atom/atom/tree/master/packages/one-dark-s

pub fn one_light() -> lustre.Config(msg)

One Light theme for prism.js Based on Atom’s One Light theme: https://github.com/atom/atom/tree/master/packages/one-ligh

pub fn pojoaque() -> lustre.Config(msg)

pojoaque theme

pub fn shades_of_purple() -> lustre.Config(msg)

Shades of Purple Theme for Prism.js @author Ahmad Awais https://twitter.com/MrAhmadAwais/ @support Follow/tweet at htt

pub fn solarized_dark_atom() -> lustre.Config(msg)

Solarized dark atom theme for prism.js Based on Atom’s atom-dark theme: https://github.com/atom/atom-dark-syntax @au

pub fn solarizedlight() -> lustre.Config(msg)

solarizedlight theme

pub fn synthwave84() -> lustre.Config(msg)

synthwave84 theme

pub fn tomorrow() -> lustre.Config(msg)

prism.js tomorrow night eighties for JavaScript, CoffeeScript, CSS and HTML Based on https://github.com/chriskempson/tom

pub fn twilight() -> lustre.Config(msg)

prism.js Twilight theme Based (more or less) on the Twilight theme originally of Textmate fame. @author Remy Bach

pub fn vs() -> lustre.Config(msg)

VS theme by Andrew Lock (https://andrewlock.net) Inspired by Visual Studio syntax coloring

pub fn vsc_dark_plus() -> lustre.Config(msg)

vsc dark plus theme

pub fn xonokai() -> lustre.Config(msg)

xonokai theme for JavaScript, CSS and HTML based on: https://github.com/MoOx/sass-prism-theme-base by Maxime Thirouin ~

pub fn z_touch() -> lustre.Config(msg)

z touch theme

Search Document